import { AwsCredentialIdentity } from "@aws-sdk/types";
import { HttpRequest } from "@smithy/protocol-http";
import { HttpResponse, Logger } from "@smithy/types";
/**
 * @internal
 */
export declare function createGetRequest(url: URL): HttpRequest;
/**
 * @internal
 */
export declare function getCredentials(response: HttpResponse, logger?: Logger): Promise<AwsCredentialIdentity>;
